@@ -1,11 +1,15 @@
 package DBIx::Skinny::DBD::SQLite;
 use strict;
 use warnings;
+use DBIx::Skinny::SQL;
 
 sub last_insert_id { $_[1]->func('last_insert_rowid') }
 
 sub sql_for_unixtime { return time() }
 
+sub quote    { '`' }
+sub name_sep { '.' }
+
 sub bulk_insert {
     my ($skinny, $table, $args) = @_;
 
@@ -20,5 +24,7 @@ sub bulk_insert {
     return 1;
 }
 
+sub query_builder_class { 'DBIx::Skinny::SQL' }
+
 1;
 
